use anyhow::{Context, Result};
use std::path::PathBuf;

use super::{syntax, ContentType};

#[derive(Debug)]
pub struct Content {
	pub systems: Vec<syntax::system::System>,
}

impl Content {
	pub fn new(cv: Vec<(PathBuf, ContentType)>) -> Result<Self> {
		let mut content = Self {
			systems: Vec::new(),
		};

		// These methods check intra-file consistency
		for (p, c) in cv {
			match c {
				ContentType::System(v) => content
					.add_system(v)
					.with_context(|| format!("Could not parse {}", p.display()))?,
			};
		}

		return Ok(content);
	}

	fn add_system(&mut self, toml: syntax::system::toml::SystemRoot) -> Result<()> {
		self.systems.push(syntax::system::System::parse(toml)?);
		return Ok(());
	}
}
